==> cutemaze_1.2.0.orig.tar.gz: cutemaze-1.2.0/translations/cutemaze_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Impossible de charger le dernier jeu. Démarrage d&apos;une nouvelle partie.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 écoulées</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 étapes franchies</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 cibles restantes sur %2</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Contrôle</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nouvelle partie</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Chasse et tue</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Retour sur trace récursif</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation> Tas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Tas 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Tas 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Tas 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Tas 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithme :</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cibles :</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Chasse et tue</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Retour sur trace récursif</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Tas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Tas 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Tas 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Tas 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Tas 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Scores de CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Étapes</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithme</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Félicitations !</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Votre score est dans le Top 10.
Veuillez saisir votre nom :</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Partie</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Montrer où vous étiez</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Afficher le nombre d&apos;étapes franchies</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Afficher le temps écoulé</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Mouvement doux</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Vers le haut :</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Vers le bas :</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Vers la gauche :</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Vers la droite :</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Changer le drapeau :</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Thèmes</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Sélectionner le fichier de thème</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Impossible de créer le répertoire de données.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Impossible de copier le fichier de thème.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Supprimer le thème sélectionné ?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Impossible de supprimer le thème sélectionné.</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>H</source>
        <translation>H</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Suggestion</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Palmarès</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;avant</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;arrière</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Préférences…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un jeu de labyrinthe de haut en bas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Utilise les icônes du thème &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>

==> cutemaze_1.2.5.orig.tar.gz: cutemaze-1.2.5/translations/cutemaze_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>Board</name>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to load previous game. A new game will be started.</source>
        <translation>Impossible de charger le dernier jeu. Démarrage d&apos;une nouvelle partie.</translation>
    </message>
    <message>
        <source>%1 elapsed</source>
        <translation>%1 écoulées</translation>
    </message>
    <message>
        <source>%1 steps taken</source>
        <translation>%1 étapes franchies</translation>
    </message>
    <message>
        <source>%1 of %2 targets remain</source>
        <translation>%1 cibles restantes sur %2</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Succès</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>En pause</translation>
    </message>
</context>
<context>
    <name>ControlButton</name>
    <message>
        <source>Shift</source>
        <translation>Maj</translation>
    </message>
    <message>
        <source>Ctrl</source>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Meta</source>
        <translation>Meta</translation>
    </message>
    <message>
        <source>Alt</source>
        <translation>Alt</translation>
    </message>
    <message>
        <source>Super</source>
        <translation>Super</translation>
    </message>
    <message>
        <source>Windows</source>
        <translation>Fenêtre</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Commande</translation>
    </message>
    <message>
        <source>Control</source>
        <translation>Contrôle</translation>
    </message>
    <message>
        <source>Option</source>
        <translation>Option</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Sélectionner la langue de l&apos;application :</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Langue du système&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Remarque</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Veuillez relancer l&apos;application pour que la modification prenne effet. </translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nouvelle partie</translation>
    </message>
    <message>
        <source>Hunt and Kill</source>
        <translation>Chasse et tue</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Retour sur trace récursif</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation> Tas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Tas 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Tas 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Tas 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Tas 5</translation>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation>Algorithme :</translation>
    </message>
    <message>
        <source>Targets:</source>
        <translation>Cibles :</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Taille :</translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Hunt and Kill</source>
        <translation>Chasse et tue</translation>
    </message>
    <message>
        <source>Kruskal</source>
        <translation>Kruskal</translation>
    </message>
    <message>
        <source>Prim</source>
        <translation>Prim</translation>
    </message>
    <message>
        <source>Recursive Backtracker</source>
        <translation>Retour sur trace récursif</translation>
    </message>
    <message>
        <source>Stack</source>
        <translation>Tas</translation>
    </message>
    <message>
        <source>Stack 2</source>
        <translation>Tas 2</translation>
    </message>
    <message>
        <source>Stack 3</source>
        <translation>Tas 3</translation>
    </message>
    <message>
        <source>Stack 4</source>
        <translation>Tas 4</translation>
    </message>
    <message>
        <source>Stack 5</source>
        <translation>Tas 5</translation>
    </message>
</context>
<context>
    <name>Scores</name>
    <message>
        <source>CuteMaze Scores</source>
        <translation>Scores de CuteMaze</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Time</source>
        <translation>Temps</translation>
    </message>
    <message>
        <source>Steps</source>
        <translation>Étapes</translation>
    </message>
    <message>
        <source>Algorithm</source>
        <translation>Algorithme</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation>Félicitations !</translation>
    </message>
    <message>
        <source>Your score has made the top ten.
Please enter your name:</source>
        <translation>Votre score est dans le Top 10.
Veuillez saisir votre nom :</translation>
    </message>
</context>
<context>
    <name>Settings</name>
    <message>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Partie</translation>
    </message>
    <message>
        <source>Show where you&apos;ve been</source>
        <translation>Montrer où vous étiez</translation>
    </message>
    <message>
        <source>Show number of steps taken</source>
        <translation>Afficher le nombre d&apos;étapes franchies</translation>
    </message>
    <message>
        <source>Show elapsed time</source>
        <translation>Afficher le temps écoulé</translation>
    </message>
    <message>
        <source>Smooth movement</source>
        <translation>Mouvement doux</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Contrôles</translation>
    </message>
    <message>
        <source>Move Up:</source>
        <translation>Vers le haut :</translation>
    </message>
    <message>
        <source>Move Down:</source>
        <translation>Vers le bas :</translation>
    </message>
    <message>
        <source>Move Left:</source>
        <translation>Vers la gauche :</translation>
    </message>
    <message>
        <source>Move Right:</source>
        <translation>Vers la droite :</translation>
    </message>
    <message>
        <source>Toggle Flag:</source>
        <translation>Changer le drapeau :</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Thèmes</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Ajouter</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Supprimer</translation>
    </message>
    <message>
        <source>Select Theme File</source>
        <translation>Sélectionner le fichier de thème</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Désolé</translation>
    </message>
    <message>
        <source>Unable to create data folder.</source>
        <translation>Impossible de créer le répertoire de données.</translation>
    </message>
    <message>
        <source>Unable to copy theme file.</source>
        <translation>Impossible de copier le fichier de thème.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Question</translation>
    </message>
    <message>
        <source>Remove the selected theme?</source>
        <translation>Supprimer le thème sélectionné ?</translation>
    </message>
    <message>
        <source>Unable to remove the selected theme.</source>
        <translation>Impossible de supprimer le thème sélectionné.</translation>
    </message>
    <message>
        <source>Show Hint:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>CuteMaze</source>
        <translation>CuteMaze</translation>
    </message>
    <message>
        <source>P</source>
        <translation>P</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Afficher</translation>
    </message>
    <message>
        <source>Ctrl++</source>
        <translation>Ctrl++</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>About</source>
        <translation>À propos de…</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>À propos de &amp;Qt</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Jeu</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nouveau</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pause</translation>
    </message>
    <message>
        <source>&amp;Hint</source>
        <translation>&amp;Suggestion</translation>
    </message>
    <message>
        <source>High &amp;Scores</source>
        <translation>&amp;Palmarès</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Quitter</translation>
    </message>
    <message>
        <source>Zoom &amp;In</source>
        <translation>Zoom &amp;avant</translation>
    </message>
    <message>
        <source>Zoom &amp;Out</source>
        <translation>Zoom &amp;arrière</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Paramètres</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Langue de l&apos;application…</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Préférences…</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Aide</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>À &amp;propos de…</translation>
    </message>
    <message>
        <source>A top-down maze game</source>
        <translation>Un jeu de labyrinthe de haut en bas</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2007-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2007-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Icons are from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; theme</source>
        <translation>Utilise les icônes du thème &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Distribué sous licence GNU &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
</context>
</TS>
